/***************************************************************
 * Name:      wx001Main.cpp
 * Purpose:   Code for Application Frame
 * Author:    Salvador Pozo (salvador@conclase.net)
 * Created:   2024-04-04
 * Copyright: Salvador Pozo (https://conclase.net)
 * License:
 **************************************************************/

#ifdef WX_PRECOMP
#include "wx_pch.h"
#endif
#include <wx/imagpng.h>

#include "wx001Main.h"
#include "open-file16x16.xpm"
#include "save-file16x16.xpm"

//helper functions
enum wxbuildinfoformat {
    short_f, long_f };

wxString wxbuildinfo(wxbuildinfoformat format)
{
    wxString wxbuild(wxVERSION_STRING);

    if (format == long_f )
    {
#if defined(__WXMSW__)
        wxbuild << _T("-Windows");
#elif defined(__WXMAC__)
        wxbuild << _T("-Mac");
#elif defined(__UNIX__)
        wxbuild << _T("-Linux");
#endif

#if wxUSE_UNICODE
        wxbuild << _T("-Unicode build");
#else
        wxbuild << _T("-ANSI build");
#endif // wxUSE_UNICODE
    }

    return wxbuild;
}

BEGIN_EVENT_TABLE(wx001Frame, wxFrame)
    EVT_CLOSE(wx001Frame::OnClose)
    EVT_MENU(idMenuQuit, wx001Frame::OnQuit)
    EVT_MENU(idMenuAbout, wx001Frame::OnAbout)
    EVT_MENU(idMenuCheck, wx001Frame::OnCheck)
    EVT_MENU_RANGE(idMenuRadio1, idMenuRadio3, wx001Frame::OnRadio)
    EVT_CONTEXT_MENU(wx001Frame::OnContextMenu)
END_EVENT_TABLE()

wx001Frame::wx001Frame(wxFrame *frame, const wxString& title)
    : wxFrame(frame, -1, title), marca(false), radio(2)
{
    wxImage::AddHandler(new wxXPMHandler);
    // Crear el menú contextual:
    popupMenu = new wxMenu(_T(""));
    popupMenu->Append(idOpcion1, _T("Opción &1"), _T("Opción 1"));
    popupMenu->Append(idOpcion2, _T("Opción &2"), _T("Opción 2"));
    popupMenu->Append(idOpcion3, _T("Opción &3"), _T("Opción 3"));
    popupMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);
    popupMenu->Append(idMenuQuit, _T("&Salir\tAlt-F4"), _T("Abandonar la aplicación"));

    // create a menu bar
    wxMenuBar* mbar = new wxMenuBar();
    wxMenu* fileMenu = new wxMenu(_T(""));

    wxBitmapBundle bmba = wxBitmapBundle(openfile); // = wxBitmapBundle::FromFiles(openfile);
    wxMenuItem *abrir = fileMenu->Append(idMenuAbrir, _T("&Abrir...\tCtrl-F"), _T("Abrir un documento"));
    abrir->SetBitmap(bmba);

    fileMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);

    wxBitmapBundle bmbs = wxBitmapBundle(savefile);
    wxMenuItem *guardar = fileMenu->Append(idMenuGuardar, _("&Guardar...\tCtrl-S"), _("Guardar un documento"));
    guardar->SetBitmap(bmbs);

    fileMenu->Append(idMenuQuit, _("&Salir\tAlt-F4"), _("Abandonar la aplicación"));
    fileMenu->Append(-1, _T(""), _T(""), wxITEM_SEPARATOR);
    wxMenuItem *item = new wxMenuItem(__null, idMenuCheck, _("&Marcar\tF3"), _("Opción marcable"), wxITEM_CHECK);
    fileMenu->Append(item);
    fileMenu->Append(idMenuRadio1, _T("Radio &1\tF5"), _T("Item radio 1"), wxITEM_RADIO);
    fileMenu->Append(idMenuRadio2, _T("Radio &2\tF6"), _T("Item radio 2"), wxITEM_RADIO);
    fileMenu->Append(idMenuRadio3, _T("Radio &3\tF7"), _T("Item radio 3"), wxITEM_RADIO);
    mbar->Append(fileMenu, _("&Fichero"));

    wxMenu* helpMenu = new wxMenu(_T(""));
    helpMenu->Append(idMenuAbout, _T("&Sobre...\tF1"), _T("Muestra información sobre ésta aplicación"));
    mbar->Append(helpMenu, _T("&Ayuda"));

    SetMenuBar(mbar);

    item->Check(marca);
    fileMenu->Enable(idMenuRadio3, false);
    mbar->FindItem(idMenuRadio1+radio)->Check();

//    Connect(idMenuQuit, wxEVT_MENU, (wxObjectEventFunction)&wx001Frame::OnQuit);
//    Disconnect(idMenuQuit, wxEVT_MENU);
    // create a status bar with some information about the used wxWidgets version
    CreateStatusBar(2);
    SetStatusText(_T("Hola"),0);
    SetStatusText(wxbuildinfo(short_f), 1);
}


wx001Frame::~wx001Frame()
{
    delete popupMenu;
}

void wx001Frame::OnClose(wxCloseEvent &event)
{
    Destroy();
}

void wx001Frame::OnQuit(wxCommandEvent &event)
{
    Destroy();
}

void wx001Frame::OnCheck(wxCommandEvent& event) {
    marca = event.IsChecked();
}

void wx001Frame::OnRadio(wxCommandEvent& event) {
    radio = event.GetId() - idMenuRadio1;
}

void wx001Frame::OnAbout(wxCommandEvent &event)
{
    wxString msg = wxbuildinfo(long_f);
    wxMessageBox(msg, _T("Bienvenido a ..."));
}

void wx001Frame::OnContextMenu(wxContextMenuEvent& event) {
    PopupMenu(popupMenu);
}

